@@ -14,11 +14,25 @@ Trustworthy
 Module      :  Lens.Micro
 Copyright   :  (C) 2013-2016 Edward Kmett, 2015-2016 Artyom
 License     :  BSD-style (see the file LICENSE)
+
+This module provides the essential functionality. There are other packages in the microlens family – mix and match them at will. If you're writing an app, you want <http://hackage.haskell.org/package/microlens-platform microlens-platform> – it provides the most functionality.
+
+* <http://hackage.haskell.org/package/microlens-mtl microlens-mtl> – (@+=@) and friends, @use@, @zoom@\/@magnify@
+* <http://hackage.haskell.org/package/microlens-th microlens-th> – @makeLenses@ and @makeFields@
+* <http://hackage.haskell.org/package/microlens-ghc microlens-ghc> – everything in microlens + instances to make @each@\/@at@\/@ix@ usable with arrays, @ByteString@, and containers
+* <http://hackage.haskell.org/package/microlens-platform microlens-platform> – microlens-ghc + microlens-mtl + microlens-th + instances for @Text@, @Vector@, and @HashMap@
+* <http://hackage.haskell.org/package/microlens-contra microlens-contra> – @Fold@ and @Getter@ that are exact copies of types in lens
+
+Unofficial:
+
+* <http://hackage.haskell.org/package/microlens-aeson microlens-aeson> – a port of <http://hackage.haskell.org/package/lens-aeson lens-aeson>
+
 -}
 module Lens.Micro
 (
   (&),
   -- $ampersand-note
+  (<&>),
 
   -- * Setter: modifies something in a structure
   -- $setters-note
@@ -142,6 +156,35 @@ or this:
 @
 -}
 
+{- |
+('<&>') is flipped ('<$>'):
+
+@
+x '<&>' f = f '<$>' x
+@
+
+It's often useful when writing lenses. For instance, let's say you're writing 'ix' for @Map@; if the key is found in the map, you have to apply a function to it and then change the map based on the new value – which requires a lambda, like this:
+
+@
+'ix' key f map = case Map.lookup key map of
+     Just val -> (\\val' -> Map.insert key val' map) '<$>' f val
+     Nothing  -> 'pure' map
+@
+
+With ('<&>') you can get rid of parentheses and move the long lambda expression to the right of the value (like when you use '>>='):
+
+@
+'ix' key f map = case Map.lookup key map of
+     Just val -> f val '<&>' \\val' -> Map.insert key val' map
+     Nothing  -> 'pure' map
+@
+-}
+(<&>) :: Functor f => f a -> (a -> b) -> f b
+(<&>) x f = f <$> x
+{-# INLINE (<&>) #-}
+
+infixl 1 <&>
+
 -- Setting -----------------------------------------------------------------
 
 {- $setters-note
@@ -782,7 +825,9 @@ filtered :: (a -> Bool) -> 'Traversal'' a a
 filtered p s = if p s then f s else 'pure' s
 @
 
-By the way, note that 'filtered' can generate illegal traversals – sometimes this can bite you. For instance, take @evens@:
+By the way, note that 'filtered' can generate illegal traversals – sometimes this can bite you. In particular, an optimisation that should be safe becomes unsafe. (To the best of my knowledge, this optimisation never happens automatically. If you just use 'filtered' to modify/view something, you're safe. If you don't define any traversals that use 'filtered', you're safe too.)
+
+Let's use @evens@ as an example:
 
 @
 evens = 'filtered' 'even'
@@ -800,7 +845,7 @@ Unfortunately, in case of @evens@ this isn't a correct optimisation:
 
   * the right-side variant applies @f@ and @g@ to all even numbers
 
-Of course, when you are careful and know what you're doing, you won't try to make such an optimisation. However, if you export an illegal traversal created with 'filtered' and someone tries to use it, ne might mistakenly assume that it's legal, do the optimisation, and silently get an incorrect result.
+Of course, when you are careful and know what you're doing, you won't try to make such an optimisation. However, if you export an illegal traversal created with 'filtered' and someone tries to use it, they might mistakenly assume that it's legal, do the optimisation, and silently get an incorrect result.
 
 If you are using 'filtered' with some another traversal that doesn't overlap with -whatever the predicate checks-, the resulting traversal will be legal. For instance, here the predicate looks at the 1st element of a tuple, but the resulting traversal only gives you access to the 2nd:
 
